---------------------------------------------------------------------------------------------------
--
-- Name:		Constants package
--
-- Project:		ADSP-2191 Host Port Booting
-- File Name:	pack_const.vhd
--
---------------------------------------------------------------------------------------------------
--
-- Description:	This file contains constant declarations that are used throughout the project.
--
---------------------------------------------------------------------------------------------------

LIBRARY ieee;
USE ieee.std_logic_1164.ALL;

PACKAGE pack_const IS
	-- version of PLD design
	CONSTANT PLD_VERSION		: INTEGER := 0101;

	-- value for watchdog counter time out (about 0.1 s, based on a 50 MHz clock input)
	CONSTANT MAX_WD_VALUE		: INTEGER := 5000000;

	-- Host Port signals
	CONSTANT HCMS_ASSERTED		: STD_LOGIC := '0';
	CONSTANT HCMS_DEASSERTED	: STD_LOGIC := '1';
	CONSTANT HCIOMS_ASSERTED	: STD_LOGIC := '0';
	CONSTANT HCIOMS_DEASSERTED	: STD_LOGIC := '1';
	CONSTANT HALE_ASSERTED		: STD_LOGIC := '0';
	CONSTANT HALE_DEASSERTED	: STD_LOGIC := '1';
	CONSTANT HWR_ASSERTED		: STD_LOGIC := '0';
	CONSTANT HWR_DEASSERTED		: STD_LOGIC := '1';
	CONSTANT HRD_ASSERTED		: STD_LOGIC := '0';
	CONSTANT HRD_DEASSERTED		: STD_LOGIC := '1';
	CONSTANT HACK_ASSERTED		: STD_LOGIC := '1';
	CONSTANT HACK_DEASSERTED	: STD_LOGIC := '0';

	-- External Port signals
	CONSTANT ECS_ASSERTED		: STD_LOGIC := '0';
	CONSTANT EWR_ASSERTED		: STD_LOGIC := '0';
	CONSTANT EWR_DEASSERTED		: STD_LOGIC := '1';
	CONSTANT ERD_ASSERTED		: STD_LOGIC := '0';
	CONSTANT ERD_DEASSERTED		: STD_LOGIC := '1';
	CONSTANT EACK_ASSERTED		: STD_LOGIC := '1';
	CONSTANT EACK_DEASSERTED	: STD_LOGIC := '0';

	-- address mapping for different access spaces
	CONSTANT HP_DM_ADDRESS		: STD_LOGIC_VECTOR(3 DOWNTO 0) := "0000";	-- HP address cycle for DM
	CONSTANT HP_DM_DATA			: STD_LOGIC_VECTOR(3 DOWNTO 0) := "0001";	-- HP data cycle to DM
	CONSTANT HP_PM_ADDRESS		: STD_LOGIC_VECTOR(3 DOWNTO 0) := "0010";	-- HP address cycle for PM
	CONSTANT HP_PM_DATA			: STD_LOGIC_VECTOR(3 DOWNTO 0) := "0011";	-- HP data cycle to PM
	CONSTANT HP_IO_ADDRESS		: STD_LOGIC_VECTOR(3 DOWNTO 0) := "0100";	-- HP address cycle for IO
	CONSTANT HP_IO_DATA			: STD_LOGIC_VECTOR(3 DOWNTO 0) := "0101";	-- HP data cycle to IO
	CONSTANT REG_VERSION		: STD_LOGIC_VECTOR(3 DOWNTO 0) := "1000";	-- access to reg VERSION

	-- configuration signals for Host Port state machine (must match address mapping)
	CONSTANT ADDRESS_CYCLE		: STD_LOGIC := '0';	-- Bit 0 for address mapping above
	CONSTANT MEM_SPACE			: STD_LOGIC := '0';	-- Bit 2 for address mapping above
	CONSTANT WRITE_ACCESS		: STD_LOGIC := '0';	-- ECS_ASSERTED OR EWR_ASSERTED

	-- general signal assignments inside the FPGA
	CONSTANT ASSERTED			: STD_LOGIC := '1';
	CONSTANT DEASSERTED			: STD_LOGIC := '0';
END pack_const;